﻿define("fotowareintegration/editors/FotoWareThumbnailSelector",[
  // dojo
  "dojo/_base/declare",
  "dojo/when",
  "dojo/on",
  "dojo/topic",
    "dojo/dom-class",
    "dojo/ready",
    "dojo/_base/lang",
  // dijit
  "dijit/focus",
  "dijit/ProgressBar",
  // epi
  "epi/Url",
  "epi/routes",
  "epi/shell/dnd/Target",
  "epi/shell/DialogService",
  // epi-cms
  "epi-cms/core/ContentReference",
  "epi-cms/widget/MediaSelector",
  "epi-cms/contentediting/_ContextualContentContextMixin",
  "epi-cms/command/UploadContent",
  "epi-cms/widget/UploadUtil",
  "epi-cms/widget/viewmodel/MultipleFileUploadViewModel",
    "epi-cms/widget/LocalFolderUploader",
    "dojo/text!./templates/FotoWareThumbnailSelector.html",
  "epi/i18n!epi/cms/nls/episerver.cms.widget.thumbnailselector",
  "epi-cms/widget/FilesUploadDropZone"
], function(
  // dojo
  declare,
  when,
  on,
  topic,
    domClass,
    ready,
  lang,
  // dijit
  focusManager,
  ProgressBar,
  // epi
  Url,
  routes,
  Target,
  dialogService,
  ContentReference,
  MediaSelector,
  _ContextualContentContextMixin,
  UploadContent,
  UploadUtil,
  MultipleFileUploadViewModel,
    LocalFolderUploader,
    template,
  resources
) {
    
    var _dropFileMixin2 = declare(_ContextualContentContextMixin, {
        // summary:
        //      This mixin is responsible for the local file upload
        // tags:
        //      internal

        // _dialogService: [private] epi/shell/DialogService
        //      The dialog service. Defaults to epi/shell/DialogService.
        _dialogService: null,
        loaded: false,
        uploadDisabledMessage: "Drag and drop feature has been disabled, please use FotoWare.",
        fotowarepath: null,
        fotowareiconpath: null,
        fotowaretenanturl: null,
        fotowaremodulepath: null,
        fwWin: null,
        pluginurl: null,
        disableMediaSelector: null,
        // allowedExtensions: [public] Array
        //      List of file extensions that may be dropped onto the editor
        allowedExtensions: [],
        postCreate: function () {

        ready(setTimeout(lang.hitch(this, function () {//inte optimalt med timeout, men funkar inte annars när _setValue sätts on init
                 this.loaded = true;
            }), 100));

        this.inherited(arguments);
      this._dialogService = this._dialogService || dialogService;

      if (this._currentContext.currentMode === "create") {
        return;
      }

      this.uploadCommand = new UploadContent({
        viewModel: this
      });

      when(this.getCurrentContent()).then(
        function(contentItem) {
          this._dropZone.set("settings", {
            enabled: true,
            validSelection: true,
            dropFolderName: this.getContextualRootName(contentItem),
            descriptionTemplate: resources.dropfile
          });
        }.bind(this)
      );
    },

    _onButtonClick: function() {
      if (
        this.progressBar.progress &&
        this.progressBar.progress !== this.progressBar.maximum
      ) {
        return;
      }

      this.inherited(arguments);
    },

    // Custom function for FotoWare integration to trigger opening of dialog.
      _onFotoWareButtonClick: function () {
          
          this.pluginurl = this.fotowarepath +"ClientResources/plugin/fotoware.html?fotowareBaseUrl=" +
              this.fotowaretenanturl +
              "/fotoweb/widgets/selection&insertMultiple=false&";


          this.fwWin = window.open(
              this.pluginurl + Math.random(),
              "fwWinName",
              //"");
                "width=1200,height=800,resizable=yes,scrollbars");

          window.fotowarePlugin = this;//have to make it global
          window.addEventListener("message", window.fotowarePlugin._listener, false);
        
        //this.inherited(arguments);
        },
        _listener: function (event) {
            //console.log("meddelande", event);

            //ta hand om loggedinSuccess
            if (event.data == "loggedinSuccess") {
                window.fotowarePlugin.fwWin.location = window.fotowarePlugin.pluginurl + Math.random();
                return;
            }

            switch (event.data.event) {
            case 'assetSelected':
                    window.fotowarePlugin.fwWin.close();

                $.ajax({
                    url: window.fotowarePlugin.fotowaremodulepath + "authentication/fetchcf",
                    type: 'GET',
                    async: false,
                    data: {
                        hostcontent: "",
                        image: event.data.asset.href
                    },
                    dataType: 'json',
                    success: function (data) {
                        window.fotowarePlugin._setValueAndFireOnChange( data + "");//bör bara string 
                    },
                    error: function (data) {
                        window.fotowarePlugin._dialogService.alert(data.statusText);
                    }
                });

                break;
            case 'selectionWidgetCancel':
                window.fotowarePlugin.fwWin.close();
                break;

            default:

            }
        },

    upload: function(fileList) {
      var uploader = new LocalFolderUploader({
        model: new MultipleFileUploadViewModel({
          store: this._store,
          query: this.query
        }),
        // we decide to not show the thumbnail & progressbar if the first chunk is bigger than 40% of the whole image
        uploadProgressThreshold: 40,
        // show thumbnails on for images smaller than 50 megabytes to avoid hanging the browser by the File API
        thumbnailMaxFileSize: 50 * 1024 * 1024
      });

      uploader.own(
        on(
          uploader,
          "uploadProgress",
          function(progress) {
            if (this._destroyed) {
              return;
            }

            this.progressBar.update({ progress: progress });
          }.bind(this)
        )
      );

      uploader.own(
        on(
          uploader,
          "uploadFilePreview",
          function(fileBytes, fileName) {
            if (this._destroyed) {
              return;
            }

            domClass.add(this.domNode, "uploading");
            this.set("selectedContentName", resources.uploading + fileName);
            this.set("previewUrl", fileBytes);
            this.thumbnail.src = fileBytes;
          }.bind(this)
        )
      );

      uploader.own(
        uploader.on(
          "uploadComplete",
          function(uploadFiles) {
            if (this._destroyed) {
              return;
            }

            this.progressBar.update({ progress: 0 });
            focusManager.focus(this.button.domNode); // we need to focus the control so we can trigger the 'onChange' immediately
            domClass.remove(this.domNode, "uploading");

            // handle upload errors, first a general error that causes an empty file list to come back from the server
            if (!uploadFiles || uploadFiles.length === 0) {
              this.set("value", this.value);
                this._
                Service.alert(resources.failed);
              return;
            }
            // handle a custom upload error, for example file size exceeded and similar
            if (uploadFiles[0].statusMessage) {
              this.set("value", this.value);
              this._dialogService.alert(uploadFiles[0].statusMessage);
              return;
            }

            this.set("value", uploadFiles[0].contentLink);
            this.onChange(this.value);
            // publish this topic so that the uploaded image is shown in the Assets Pane immediately
            topic.publish("/epi/cms/upload", this.assetsFolderLink);
          }.bind(this)
        )
      );

      uploader.upload(fileList);
    },

    _refreshTargetUploadContent: function() {
      // We need to handle scenarios when user drops images on a page that does not have assets folder yet.
      // We could try to reuse the logic from ContextualContentForestStoreModel.js & _ContextualContentContextMixin.js
      // The same issue happens in TinyMCE after d&d an image file to a new page that does not have a folder yet.
      var self = this;

      if (
        this.assetsFolderLink &&
        !this.isPseudoContextualRoot({ contentLink: this.assetsFolderLink })
      ) {
        return this.assetsFolderLink;
      }

      function getAssetsFolderLink(contentItem) {
        if (
          !self.isPseudoContextualRoot({
            contentLink: contentItem.assetsFolderLink
          })
        ) {
          return contentItem.assetsFolderLink;
        }

        return self._store
          .refresh(contentItem.contentLink)
          .then(function(refreshedContent) {
            return refreshedContent.assetsFolderLink;
          });
      }

      return when(this.getCurrentContent()).then(function(contentItem) {
        return when(getAssetsFolderLink(contentItem)).then(function(
          contentAssetsLink
        ) {
          self.assetsFolderLink = new ContentReference(contentAssetsLink)
            .createVersionUnspecificReference()
            .toString();
          self.query.references = [self.assetsFolderLink];
          return when(self._store.get(contentAssetsLink)).then(function(
            contentAssetFolderContent
          ) {
            self.uploadCommand.set("model", contentAssetFolderContent);
          });
        });
      });
    },

    _onDrop: function (evt, fileList) {

        if (this.disableMediaSelector) {
            this._dialogService.alert(this.uploadDisabledMessage);
            return;
        }
      // Accept only HTML5 img tag compliant file types, editors can still use the old Assets Pane
      // if they need any other file type like *.svg or *.tiff
      fileList = UploadUtil.filterFileOnly(fileList);
      if (!fileList || fileList.length !== 1) {
        this._dialogService.alert(resources.singleimage);
        return;
      }
      var fileName = fileList[0].name
        .split(".")
        .pop()
        .toLowerCase();
      if (this.allowedExtensions.indexOf(fileName) === -1) {
        this._dialogService.alert(resources.wrongfileformat);
        return;
      }

      when(this._refreshTargetUploadContent()).then(
        function() {
          this.uploadCommand.set("fileList", fileList);
          this.uploadCommand.execute();
        }.bind(this)
      );
    }
    });
    


    return declare([MediaSelector, _dropFileMixin2], {
    // summary:
    //      Represents the widget to select ContentReference.
    // tags:
    //      internal

    resources: resources,
    templateString: template,

    _setPreviewUrlAttr: function(value) {
      this.inherited(arguments);
      domClass.toggle(this.displayNode, "dijitHidden", !value);
      domClass.toggle(this.actionsContainer, "dijitHidden", value);
      },


    _getThumbnailUrl: function(content) {
      var url = new Url(
        routes.getActionPath({
          moduleArea: "CMS",
          controller: "Thumbnail",
          action: "Generate"
        })
      );
      url.query = {
        contentLink: content.contentLink,
        "epi.preventCache": new Date().valueOf()
      };
      return url;
    },

    _updateDisplayNode: function(content) {
      this.inherited(arguments);
      if (content) {
        this.thumbnail.src = this._getThumbnailUrl(content).toString();
      }
      this.stateNode.title = content ? content.name : "";
      },

    postCreate: function() {
      this.inherited(arguments);
      this.query = { query: "getchildren", allLanguages: true };
      },
      startup: function () {
        this.inherited(arguments);
        
    },

      _setValueAttr: function (value) {
          if (this.disableMediaSelector && this.loaded && value!=null) {
              this._dialogService.alert(this.uploadDisabledMessage);
              return;
          }
          this.inherited(arguments);
    }
      ,

    _onButtonClick: function() {
      if (this.readOnly) {
        return;
        }

        if (this.disableMediaSelector) {
            this._onFotoWareButtonClick();
            return;
        }
            

      this.inherited(arguments);
    },

    _setReadOnlyAttr: function(value) {
      this.inherited(arguments);
      this.button.domNode.style.display = "";
      this.button.set("readOnly", value);
    }
  });
});
