﻿using EPiServer;
using EPiServer.Core;
using FotoWare.PlugIns.Episerver;
using FotoWare.PlugIns.Episerver.Interfaces;
using System;
using System.Linq;

namespace AlloyTemplates.FotoWare
{
    public class DateTimeFolderResolver : IFolderResolver
    {
        private readonly IFotoWareSettings _fotowareSettings;
        private readonly IContentRepository _contentRepository;

        public DateTimeFolderResolver(IFotoWareSettings fotowareSettings, IContentRepository contentRepository)
        {
            _fotowareSettings = fotowareSettings;
            _contentRepository = contentRepository;
        }

        public ContentReference GetAssetFolder(AssetInformation assetInformation, FotoWareItemMetadata dataItem)
        {
            var childFolders = _contentRepository.GetChildren<ContentFolder>(_fotowareSettings.RootFolderId);
            var year = DateTime.Now.Year.ToString();
            var month = DateTime.Now.Month.ToString();

            var yearFolder = childFolders.FirstOrDefault(f => string.Equals(f.Name, year, StringComparison.OrdinalIgnoreCase)) ?? CreateFolder(year, _fotowareSettings.RootFolderId);
            var monthFolders = _contentRepository.GetChildren<ContentFolder>(yearFolder.ContentLink);
            var currentMonthFolder = monthFolders.FirstOrDefault(f => string.Equals(f.Name, month, StringComparison.OrdinalIgnoreCase)) ?? CreateFolder(month, yearFolder.ContentLink);

            return currentMonthFolder.ContentLink;
        }

        private ContentFolder CreateFolder(string folderName,ContentReference parentFolder)
        {
            var newFolder = _contentRepository.GetDefault<ContentFolder>(parentFolder);
            newFolder.Name = folderName;
            var folderReference =  _contentRepository.Save(newFolder);

            return _contentRepository.Get<ContentFolder>(folderReference);
        }
    }
}