﻿using EPiServer.Core;
using FotoWare.PlugIns.Episerver.Interfaces;
using System;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.Configuration;
using System.Linq;

namespace FotoWare.PlugIns.Episerver
{
    // Example of settings implementation for Fotoware. Implement and register your custom instance in the IOC container to override default behaviour.
    //[ServiceConfiguration(typeof(IFotoWareSettings))]
    public class FotoWareSettings : IFotoWareSettings
    {
        public FotoWareSettings()
        {
            MetadataConfiguration = new NameValueCollection
            {
                {"5", "Name"},
                {"25", "Keywords"},
                {"80", "Photographers"},
                {"115", "Copyright"},
                {"120", "Description"}
            };
        }

        public string AllowedTypes => ConfigurationManager.AppSettings["FotoWare:AllowedTypes"]?? ".jpg,.jpeg,.jpe,.gif,.bmp,.png";

        public string ApiToken => ConfigurationManager.AppSettings["FotoWare:ApiToken"];

        public string ClientId => ConfigurationManager.AppSettings["FotoWare:ClientId"];

        public string ClientSecret => ConfigurationManager.AppSettings["FotoWare:ClientSecret"];

        public string FotoWareTenantUrl => ConfigurationManager.AppSettings["FotoWare:TenantUrl"];

        /// <summary>
        /// Used in sheduled Job for full import
        /// </summary>
        public IEnumerable<string> ArchiveUrlsToSynchronize
        {
            get
            {
               var archives = ConfigurationManager.AppSettings["FotoWare:ArchiveUrlsToSynchronize"];
               if (!string.IsNullOrWhiteSpace(archives))
               {
                   return archives.Split(',');
               }

               return Enumerable.Empty<string>();
            }
        }


        public NameValueCollection MetadataConfiguration { get; }

        public int PreferredDownloadWidth
        {
            get
            {
                if (!int.TryParse(ConfigurationManager.AppSettings["FotoWare:PreferredDownloadWidth"], out int size))
                {
                    size = 1400;
                }

                return size;
            }
        }

        public string PresetUrl => ConfigurationManager.AppSettings["FotoWare:PresetUrl"];

        public string RedirectUri => ConfigurationManager.AppSettings["FotoWare:RedirectUri"];

        public ContentReference RootFolderId

        {
            get
            {
                if (!int.TryParse(ConfigurationManager.AppSettings["FotoWare:RootFolderId"], out int id))
                {
                    throw new Exception("FotoWare configuration not complete, FotoWare:RootFolderId in appsettings web.config not set to a valid folder id");
                }
                return new ContentReference(ConfigurationManager.AppSettings["FotoWare:RootFolderId"]);
            }
        }
    }
}