﻿using System;
using System.Collections.Generic;
using System.Reflection;
using EPiServer.Cms.Shell.UI.ObjectEditing.EditorDescriptors;
using EPiServer.Cms.Shell.UI.ObjectEditing.Internal;
using EPiServer.Core;
using EPiServer.ServiceLocation;
using EPiServer.Shell.ObjectEditing;
using EPiServer.Shell.ObjectEditing.EditorDescriptors;
using FotoWare.PlugIns.Episerver.Interfaces;

namespace AlloyTemplates.FotoWare
{
    /// <summary>
    /// Example of registering an editor property for all image properties. Will override Image UIHint
    /// </summary>
    /// 
    [EditorDescriptorRegistration(TargetType = typeof(ContentReference), UIHint = "image", EditorDescriptorBehavior = EditorDescriptorBehavior.OverrideDefault)]
    public class ImageContentReferenceEditorDescriptor : ImageReferenceEditorDescriptor
    {
        public ImageContentReferenceEditorDescriptor(FileExtensionsResolver fileExtensionsResolver) : base(fileExtensionsResolver)
        {
        }

        public override void ModifyMetadata(ExtendedMetadata metadata, IEnumerable<Attribute> attributes)
        {
            ClientEditingClass = "fotowareintegration/editors/FotoWareThumbnailSelector";
            var settings = ServiceLocator.Current.GetInstance<IFotoWareSettings>();

            var version = Assembly.GetAssembly(typeof(IFotoWareSettings)).GetName().Version.ToString(fieldCount: 4);
            var path = EPiServer.Shell.Paths.ToResource("FotoWare.PlugIns.Episerver", string.Empty);

            metadata.EditorConfiguration["fotowarepath"] = path + version + "/";
            metadata.EditorConfiguration["fotowaremodulepath"] = path;
            metadata.EditorConfiguration["fotowareiconpath"] = metadata.EditorConfiguration["fotowarepath"] + "ClientResources/plugin/favicon.ico";
            metadata.EditorConfiguration["fotowaretenanturl"] = settings.FotoWareTenantUrl;
            metadata.EditorConfiguration["disableMediaSelector"] = true; //false if default can be used

            base.ModifyMetadata(metadata, attributes);
        }
    }
}
